@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from .connection import DLConnection
+from .client import DLClient
 from .exception import DLException
 from .filter import DLFilter
 from .read_params import DLReadParams
